/**
* Manage Roles
* It will be your responsibility to fine tune this template, add validations, try/catch blocks, logging, etc.
*/
component{
	
	// DI Virtual Entity Service
	property name="ormService" inject="entityService:Role";
	
	// HTTP Method Security
	this.allowedMethods = {
		index = "GET", new = "GET", edit = "GET", delete = "POST,DELETE", save = "POST,PUT"
	};
	
	/**
	* preHandler()
	*/
	function preHandler(event,rc,prc){
		event.paramValue("format","html");
	}
		
	/**
	* Listing
	*/
	function index(event,rc,prc){
		// Get all Roles
		rc.Roles = ormService.getAll();
		
		// RESTful Switch
		switch(rc.format){
			// xml,json,jsont,wddx are by default.  Add your own or remove
			case "xml" : case "json" : case "jsont" : case "wddx" :{
				event.renderData(data=rc.Roles,type=rc.format);
				break;
			}
			// HTML
			default:{
				event.setView("Roles/index");
			}
		}
	}	
	
	/**
	* New Form
	*/
	function new(event,rc,prc){
		
		// get new Role
		rc.Role = ormService.new();
		
		event.setView("Roles/new");
	}	

	/**
	* Edit Form
	*/
	function edit(event,rc,prc){
		
		// get persisted Role
		rc.Role = ormService.get( rc.roleID );
		
		event.setView("Roles/edit");
	}	
	
	/**
	* View Role mostly used for RESTful services only.
	*/
	function show(event,rc,prc){
		
		// Get requested entity by id
		rc.Role = ormService.get( rc.roleID );
		
		switch(rc.format){
			// xml,json,jsont,wddx are by default.  Add your own or remove
			case "xml" : case "json" : case "jsont" : case "wddx" :{
				event.renderData(data=rc.Role,type=rc.format);
				break;
			}
			// HTML
			default:{
				setNextEvent('Roles');
			}
		}
	}

	/**
	* Save and Update
	*/
	function save(event,rc,prc){
		
		// get Role to persist or update and populate it with incoming form
		rc.Role = populateModel(model=ormService.get( rc.roleID ),exclude="roleID");
		
		// Do your validations here
		
		// Save it
		ormService.save( rc.Role );
		
		// RESTful Handler
		switch(rc.format){
			// xml,json,jsont,wddx are by default.  Add your own or remove
			case "xml" : case "json" : case "jsont" : case "wddx" :{
				event.renderData(data=rc.Role,type=rc.format,location="/Roles/show/#rc.Role.getroleID()#");
				break;
			}
			// HTML
			default:{
				// Show a nice messagebox
				getplugin("MessageBox").info("Role Created!");
				// Redirect to listing
				setNextEvent('Roles');
			}
		}
	}	

	/**
	* Delete
	*/
	function delete(event,rc,prc){
		
		// Delete record by ID
		var removed = ormService.deleteById( rc.roleID );
		
		// RESTful Handler
		switch(rc.format){
			// xml,json,jsont,wddx are by default.  Add your own or remove
			case "xml" : case "json" : case "jsont" : case "wddx" :{
				var restData = {deleted=removed};
				event.renderData(data=restData,type=rc.format);
				break;
			}
			// HTML
			default:{
				// Show a nice messagebox
				getplugin("MessageBox").warn("Role Poofed!");
				// Redirect to listing
				setNextEvent('Roles');
			}
		}
	}	
	
}